@@ -13,7 +13,9 @@
 
 (texmacs-module (dynamic fold-menu)
   (:use (dynamic fold-edit)
-        (generic generic-menu)))
+        (generic generic-menu)
+	(generic document-menu)
+        (generic format-widgets)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Menus for direct folding and switching
@@ -30,8 +32,8 @@
 (menu-bind switch-menu
   (when (with t (tree-innermost dynamic-context?)
           (and t (switch-context? t)))
-    ("Add branch before" (switch-insert-at (focus-tree) :current))
-    ("Add branch after" (switch-insert-at (focus-tree) :var-next))
+    ("Add branch before" (switch-insert-at (focus-tree) :current #f))
+    ("Add branch after" (switch-insert-at (focus-tree) :var-next #f))
     ("Remove this branch" (switch-remove-at (focus-tree) :current))
     ---
     (when (switch-index (focus-tree))
@@ -93,10 +95,10 @@
         ("Screens" (make-screens)))
       ("Tiny" (make-switch 'tiny-switch)))
   (-> "Unroll"
-      ("Default" (make-switch 'unroll))
-      ("Compressed" (make-switch 'unroll-compressed)) 
-      ("Phantoms" (make-switch 'unroll-phantoms))
-      ("Greyed" (make-switch 'unroll-greyed))
+      ("Default" (make-unroll 'unroll))
+      ("Compressed" (make-unroll 'unroll-compressed))
+      ("Phantoms" (make-unroll 'unroll-phantoms))
+      ("Greyed" (make-unroll 'unroll-greyed))
       ---
       ("Itemize" (make-switch-list 'unroll 'itemize))
       ("Enumerate" (make-switch-list 'unroll 'enumerate))
@@ -218,24 +220,27 @@
 
 (menu-bind document-style-extra-menu
   (:require (style-has? "beamer-style"))
-  (=> "Beamer theme"
+  (-> "Beamer theme"
       (for (theme (beamer-themes))
         ((check (eval (upcase-first theme)) "v" (has-style-package? theme))
          (add-style-package theme)))))
 
 (tm-menu (focus-style-extra-menu t)
   (:require (style-has? "beamer-style"))
-  (=> "Beamer theme"
+  (-> "Beamer theme"
       (for (theme (beamer-themes))
         ((check (eval (upcase-first theme)) "v" (has-style-package? theme))
-         (add-style-package theme)))))
+         (add-style-package theme))))
+  (-> "Background color"
+      (link document-background-color-menu)))
 
 (tm-menu (focus-style-extra-icons t)
   (:require (style-has? "beamer-style"))
   (=> (balloon (eval (upcase-first (current-beamer-theme))) "Beamer theme")
       (for (theme (beamer-themes))
         ((check (eval (upcase-first theme)) "v" (has-style-package? theme))
-         (add-style-package theme)))))
+         (add-style-package theme))))
+  (link focus-background-color-icons))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Propose insertion of 'screens' tag in beamer style
@@ -250,11 +255,25 @@
         (begin
           (tree-assign! t `(document ,(tree-ref t 0)
                                      (screens (shown (document ,@(cdr l))))))
-          (if (!= (car p) 0)
+          (if (and p (!= (car p) 0))
               (apply tree-go-to `(,t 1 0 0 ,(- (car p) 1) ,@(cdr p)))))
         (begin
           (tree-assign! t `(document (screens (shown (document ,@l)))))
-          (apply tree-go-to `(,t 0 0 0 ,@p))))))
+          (if p (apply tree-go-to `(,t 0 0 0 ,@p)))))))
+
+(tm-define (remove-single-screens)
+  (let* ((t (buffer-tree))
+         (l (tree-children t)))
+    (when (tree-func? (cAr l) 'screens 1)
+      (when (tree-func? (tree-ref (cAr l) 0) 'shown 1)
+        (let* ((d (tree-ref (tree-ref (cAr l) 0) 0))
+               (b (tree->path t))
+               (p (cursor-inside? d)))
+          (when (tree-func? d 'document)
+            (with q (and (pair? p)
+                         (cons (+ (car p) (length (cDr l))) (cdr p)))
+              (tree-assign! t `(document ,@(cDr l) ,@(tree-children d)))
+              (if q (delayed (:idle 1) (go-to-path (append b q)))))))))))
 
 (tm-define (document-propose-screens?)
   (and (style-has? "beamer-style")
@@ -262,7 +281,7 @@
 
 (tm-menu (focus-document-extra-menu t)
   (:require (document-propose-screens?))
-  ("Screens" (make-switch 'screens)))
+  ("Screens" (make-screens)))
 
 (tm-menu (focus-document-extra-icons t)
   (:require (document-propose-screens?))
@@ -270,55 +289,142 @@
     ((balloon "Screens" "Make a multi-slide presentation")
      (make-screens))))
 
+(tm-define (notify-new-style style)
+  (former style)
+  (if (style-has? "beamer-style")
+      (if (not (screens-buffer?)) (make-screens))
+      (if (screens-buffer?) (remove-single-screens))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Slide titles
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (tm-define (standard-options l)
   (:require (== l 'tit))
-  (list "framed-title" "title-bar"))
+  (append (list "framed-title" "title-bar")
+          (if (style-has? "framed-title-package")
+              (list "shadowed-frames")
+              (list "shadowed-titles"))))
 
 (tm-define (parameter-show-in-menu? l)
   (:require (== l "title-theme"))
   #f)
 
 (tm-define (slide-propose-title? t)
-  (and-with u (tree-ref t :down :down)
-    (and (tree-is? u 'document)
-         (not (tree-is? u 0 'tit)))))
+  (and-with u (slide-get-document t)
+    (not (tree-is? u 0 'tit))))
 
 (tm-define (slide-insert-title t)
-  (with u (tree-ref t :down :down)
+  (and-with u (slide-get-document t)
     (tree-insert u 0 '((tit "")))
     (tree-go-to u 0 0 0)))
 
-(tm-define (search-slide-name t)
-  (cond ((tree-in? t '(shown hidden document))
-         (search-slide-name (tree-ref t 0)))
-        ((tree-is? t 'tit)
-         (texmacs->code (verbatim-expand (tm-ref t 0)) "cork"))
-        (else "")))
+(tm-define (search-slide-name t*)
+  (with t (slide-get-document t*)
+    (if (and (tree-is? t 'document)
+             (tree-is? t 0 'tit))
+        (texmacs->code (verbatim-expand (tm-ref t 0 0)) "cork")
+        "")))
 
 (tm-define (get-slide-name t i)
   (with s (search-slide-name t)
     (string-append "Slide " (number->string (+ i 1))
                    (if (== s "") "" (string-append ": " s)))))
 
-(tm-menu (focus-slides-menu t)
-  (for (i (.. 0 (tree-arity t)))
-    ((eval (get-slide-name (tree-ref t i) i))
-     (switch-to t i))))
+(tm-menu (focus-slides-menu t*)
+  (with t (slide-get-switch t*)
+    (for (i (.. 0 (tree-arity t)))
+      ((eval (get-slide-name (tree-ref t i) i))
+       (screens-switch-to i)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; Menus shen focus is on 'screens' tag
+;; Graphical slides
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-define (slide-propose-graphics? t)
+  (and-with u (slide-get-document t)
+    (or (tm-equal? u '(document ""))
+        (and (tree-func? u 'document 1)
+             (tree-is? u 0 'tit))
+        (and (tree-func? u 'document 2)
+             (tree-is? u 0 'tit)
+             (tm-equal? (tree-ref u 1) "")))))
+
+(tm-define (slide-insert-graphics t)
+  (and-with u (slide-get-document t)
+    (when (and (tree-func? u 'document 1)
+               (tree-is? u 0 'tit))
+      (tree-insert! u 1 (list "")))
+    (tree-set u :last `(gr-screen (document "")))
+    (tree-go-to u :last 0 0 0)
+    (make-graphics
+     "gr-mode" "point"
+     "gr-frame" `(tuple "scale" "1cm" (tuple "0gw" "1gh"))
+     "gr-geometry" `(tuple "geometry" "1gpar" "1gpag" "axis"))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Slide background color
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-widget (slide-page-formatter quit)
+  (let* ((col (tm->stree (slide-get-bg-color)))
+         (setter (lambda (c)
+                   (set! col c)
+                   (slide-set-bg-color col)
+                   (refresh-now "slide-color-sample"))))
+    (padded
+      (bold (text "Background color"))
+      ===
+      (hlist
+        (refreshable "slide-color-sample"
+          (resize "150px" "100px"
+            (texmacs-output `(document
+                               (block
+                                (tformat
+                                 (cwith "1" "1" "1" "1" "cell-width" "140px")
+                                 (cwith "1" "1" "1" "1" "cell-height" "90px")
+                                 (cwith "1" "1" "1" "1" "cell-vmode" "exact")
+                                 (cwith "1" "1" "1" "1" "cell-background" ,col)
+                                 (table (row (cell ""))))))
+                            `(style (tuple "generic")))))
+        // // //
+        (explicit-buttons
+          (vlist
+            ("Color" (interactive-color setter (list)))
+            ("Pattern" (open-pattern-selector setter "1cm"))
+            ("Picture" (open-background-picture-selector setter))
+            (glue #f #t 0 0))))
+      ======
+      (explicit-buttons
+        (hlist
+          >>>
+          ("Ok" (quit)))))))
+
+(tm-define (open-page-format)
+  (:require (or (inside? 'screens) (inside? 'slideshow)))
+  (dialogue-window slide-page-formatter noop "Page format"))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Menus when focus is on 'screens' tag
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (tm-define (focus-can-move? t)
-  (:require (tree-is? t 'screens))
+  (:require (screens-context? t))
   #f)
 
+(tm-menu (focus-tag-menu t)
+  (:require (screens-context? t))
+  (inert ((eval (focus-tag-name (tree-label t))) (noop) (noop)))
+  (-> (eval (upcase-first (get-init "page-type")))
+      (link document-page-size-menu))
+  (-> (eval (upcase-first (get-init-page-rendering)))
+      (link page-rendering-menu))
+  (-> "Preferences"
+      (dynamic (focus-preferences-menu t)))
+  ("Describe" (focus-help)))
+
 (tm-menu (standard-focus-menu t)
-  (:require (tree-is? t 'screens))
+  (:require (screens-context? t))
   (dynamic (focus-style-menu t))
   ---
   (dynamic (focus-tag-menu t))
@@ -328,24 +434,52 @@
   (dynamic (focus-slides-menu t))
   (assuming (slide-propose-title? t)
     ---
-    ("Title" (slide-insert-title t))))
+    ("Title" (slide-insert-title t)))
+  (assuming (slide-propose-graphics? t)
+    ---
+    ("Draw" (slide-insert-graphics t))))
+
+(tm-menu (focus-tag-icons t)
+  (:require (screens-context? t))
+  (mini #t (inert ((eval (focus-tag-name (tree-label t))) (noop))))
+  (=> (balloon (eval (upcase-first (get-init "page-type")))
+               "Paper size")
+      (link document-page-size-menu))
+  (=> (balloon (eval (upcase-first (font-family-main (get-init "font"))))
+               "Main document font")
+      (link document-short-font-menu))
+  (=> (balloon (eval (string-append (get-init "font-base-size") "pt"))
+               "Font size")
+      (link document-font-base-size-menu))
+  (=> (balloon (icon (eval (current-page-icon))) "Page layout")
+      (link page-rendering-menu))
+  (assuming (focus-has-preferences? t)
+    (=> (balloon (icon "tm_focus_prefs.xpm") "Preferences for tag")
+	(dynamic (focus-preferences-menu t))))
+  ((balloon (icon "tm_focus_help.xpm") "Describe tag")
+   (focus-help)))
 
 (tm-menu (standard-focus-icons t)
-  (:require (tree-is? t 'screens))
+  (:require (screens-context? t))
   (dynamic (focus-style-icons t))  
   //
   (minibar (dynamic (focus-insert-icons t)))
   //
   (minibar (dynamic (focus-tag-icons t)))
   //
-  (with i (tree-index (tree-down t))
-    (mini #t
-      (=> (eval (get-slide-name (tree-ref t i) i))
-          (dynamic (focus-slides-menu t)))))
+  (with u (slide-get-switch t)
+    (with i (tree-index (tree-down u))
+      (mini #t
+        (=> (eval (get-slide-name (tree-ref u i) i))
+            (dynamic (focus-slides-menu t))))))
   (assuming (slide-propose-title? t)
     //
     (minibar
-     ((balloon "Title" "Insert title") (slide-insert-title t)))))
+     ((balloon "Title" "Insert title") (slide-insert-title t))))
+  (assuming (slide-propose-graphics? t)
+    //
+    (minibar
+     ((balloon "Draw" "Draw graphics") (slide-insert-graphics t)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Menu customizations for overlays
@@ -367,12 +501,12 @@
   (:require (== l "overlay-nr"))
   #f)
 
-(define (get-overlays-menu-name t)
+(define (get-overlays-menu-name prefix t)
   (let* ((cur (overlays-current t))
          (tot (overlays-arity t)))
     (set! cur (if cur (number->string cur) "?"))
     (set! tot (if tot (number->string tot) "?"))
-    (string-append "Overlay " cur "/" tot)))
+    (string-append prefix cur "/" tot)))
 
 (tm-menu (focus-overlays-menu t)
   (for (i (.. 1 (or (+ (overlays-arity t) 1) 2)))
@@ -387,8 +521,9 @@
 (tm-menu (focus-hidden-icons t)
   (:require (overlays-context? t))
   //
-  (=> (eval (get-overlays-menu-name t))
-      (dynamic (focus-overlays-menu t))))
+  (mini #t
+    (=> (eval (get-overlays-menu-name "Overlay " t))
+        (dynamic (focus-overlays-menu t)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Menu customizations for overlay filters
@@ -409,5 +544,72 @@
 
 (tm-menu (focus-hidden-icons t)
   (:require (overlay-context? t))
+  (with p (tree-search-upwards t overlays-context?)
+    (assuming p
+      (dynamic (focus-hidden-icons p))))
   //
-  (dynamic (focus-overlay-icons t)))
+  (mini #t
+    (dynamic (focus-overlay-icons t))))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Overlays in graphics mode
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(define (proviso-name p)
+  (cond ((== p "mixed") "mixed")
+        ((tm-func? p 'show-this 1) "=")
+        ((tm-func? p 'show-from 1) ">=")
+        ((tm-func? p 'show-until 1) "<=")
+        (else "*")))
+
+(tm-menu (graphics-overlays-mode-menu)
+  (let* ((t (tree-innermost overlays-context?))
+         (cur (and t (number->string (overlays-current t)))))
+    ("This" (graphics-set-proviso `(show-this ,cur)))
+    ("From" (graphics-set-proviso `(show-from ,cur)))
+    ("Until" (graphics-set-proviso `(show-until ,cur)))
+    ("Always" (graphics-set-proviso "default"))))
+
+(tm-menu (graphics-focus-overlays-menu)
+  (with t (tree-innermost overlays-context?)
+    (assuming (nnot t)
+      ---
+      (-> "Overlay mode"
+          (link graphics-overlays-mode-menu))
+      (-> (eval (get-overlays-menu-name "Overlay " t))
+          (dynamic (focus-overlays-menu t))))))
+
+(tm-menu (graphics-focus-overlays-icons)
+  (with t (tree-innermost overlays-context?)
+    (assuming (nnot t)
+      /
+      (mini #t
+        (group "Overlay:")
+        (=> (eval (proviso-name (graphics-get-proviso)))
+            (link graphics-overlays-mode-menu))
+        (=> (eval (get-overlays-menu-name "" t))
+            (dynamic (focus-overlays-menu t)))))))
+
+(tm-menu (graphics-screens-menu)
+  (with t (tree-innermost screens-context?)
+    (assuming (nnot t)
+      ("Insert slide before" (structured-insert-horizontal t #f))
+      ("Insert slide after"  (structured-insert-horizontal t #t))
+      ("Remove slide before" (structured-remove-horizontal t #f))
+      ("Remove slide after"  (structured-remove-horizontal t #t)))))
+
+(tm-menu (graphics-overlays-manage-menu)
+  (with t (tree-innermost overlays-context?)
+    (assuming (nnot t)
+      ("Insert overlay before" (structured-insert-horizontal t #f))
+      ("Insert overlay after"  (structured-insert-horizontal t #t))
+      ("Remove overlay before" (structured-remove-horizontal t #f))
+      ("Remove overlay after"  (structured-remove-horizontal t #t)))))
+
+(tm-menu (graphics-overlays-menu)
+  (with t (tree-innermost overlays-context?)
+    (assuming (not t)
+      ("Insert overlay before" (make-gr-overlays #f))
+      ("Insert overlay after" (make-gr-overlays #t)))
+    (assuming t
+      (link graphics-overlays-manage-menu))))
