@@ -11,6 +11,13 @@
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+(cond ((os-mingw?)
+       (debug-set! stack 0))
+      ((os-macos?)
+       (debug-set! stack 2000000))
+      (else
+       (debug-set! stack 1000000)))
+
 (define boot-start (texmacs-time))
 (define remote-client-list (list))
 
@@ -51,10 +58,12 @@
 
 (define old-primitive-load primitive-load)
 (define (new-primitive-load filename)
-  ;; We explicitly circumvent guile's decision to set the current-reader
-  ;; to #f inside ice-9/boot-9.scm, try-module-autoload
-  (with-fluids ((current-reader read))
-               (old-primitive-load filename)))
+  (if (member (scheme-dialect) (list "guile-a" "guile-b"))
+      (old-primitive-load filename)
+      ;; We explicitly circumvent guile's decision to set the current-reader
+      ;; to #f inside ice-9/boot-9.scm, try-module-autoload
+      (with-fluids ((current-reader read))
+                   (old-primitive-load filename))))
 
 (if developer-mode?
     (begin
@@ -116,9 +125,12 @@
 (lazy-define (utils library cursor) notify-cursor-moved)
 (lazy-define (utils cas cas-out) cas->stree)
 (lazy-define (utils plugins plugin-cmd) pre-serialize verbatim-serialize)
+(lazy-define (utils test test-convert) delayed-quit
+             build-manual build-ref-suite run-test-suite)
 (use-modules (utils library smart-table))
 (use-modules (utils plugins plugin-convert))
 (use-modules (utils misc markup-funcs))
+(use-modules (utils misc artwork))
 (use-modules (utils handwriting handwriting))
 (define supports-email? (url-exists-in-path? "mmail"))
 (if supports-email? (use-modules (utils email email-tmfs)))
@@ -139,13 +151,16 @@
 (lazy-keyboard (texmacs keyboard prefix-kbd) always?)
 (lazy-keyboard (texmacs keyboard latex-kbd) always?)
 (lazy-menu (texmacs menus file-menu) file-menu go-menu
-           new-file-menu load-menu save-menu print-menu close-menu)
+           new-file-menu load-menu save-menu
+           print-menu print-menu-inline close-menu)
 (lazy-menu (texmacs menus edit-menu) edit-menu)
-(lazy-menu (texmacs menus view-menu) view-menu)
+(lazy-menu (texmacs menus view-menu) view-menu texmacs-bottom-toolbars)
 (lazy-menu (texmacs menus tools-menu) tools-menu)
 (lazy-menu (texmacs menus preferences-menu) preferences-menu page-setup-menu)
 (lazy-menu (texmacs menus preferences-widgets) open-preferences)
 (use-modules (texmacs menus main-menu))
+(lazy-define (texmacs menus file-menu) recent-file-list recent-directory-list)
+(lazy-define (texmacs menus view-menu) set-bottom-bar test-bottom-bar?)
 (tm-define (notify-set-attachment name key val) (noop))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
@@ -156,35 +171,45 @@
 (lazy-menu (generic format-menu) format-menu
            font-size-menu color-menu horizontal-space-menu
            transform-menu specific-menu
+           text-font-effects-menu text-effects-menu
            vertical-space-menu indentation-menu line-break-menu
            page-header-menu page-footer-menu page-numbering-menu
            page-break-menu)
 (lazy-menu (generic document-menu) document-menu
+           cite-texmacs-menu cite-texmacs-short-menu
            project-menu document-style-menu global-language-menu)
-(lazy-menu (generic document-part) document-part-menu project-manage-menu)
+(lazy-menu (generic document-part)
+           preamble-menu document-part-menu project-manage-menu)
 (lazy-menu (generic insert-menu) insert-menu texmacs-insert-menu
-           texmacs-insert-icons
-           insert-link-menu insert-image-menu insert-animation-menu)
-(lazy-define (generic document-edit) update-document)
+           texmacs-insert-icons insert-link-menu insert-image-menu)
+(lazy-define (generic document-edit) update-document
+             get-init-page-rendering init-page-rendering)
 (lazy-define (generic generic-edit) notify-activated notify-disactivated)
 (lazy-define (generic generic-doc) focus-help)
-(lazy-define (generic generic-widgets) search-toolbar replace-toolbar
+(lazy-define (generic search-widgets) search-toolbar replace-toolbar
              open-search toolbar-search-start interactive-search
              open-replace toolbar-replace-start interactive-replace
              search-next-match)
+(lazy-define (generic spell-widgets) spell-toolbar
+             open-spell toolbar-spell-start interactive-spell)
 (lazy-define (generic format-widgets) open-paragraph-format open-page-format)
+(lazy-define (generic pattern-selector)
+             open-pattern-selector open-background-picture-selector)
 (lazy-define (generic document-widgets) open-source-tree-preferences
              open-document-paragraph-format open-document-page-format
              open-document-metadata open-document-colors)
 (tm-property (open-search) (:interactive #t))
 (tm-property (open-replace) (:interactive #t))
 (tm-property (open-paragraph-format) (:interactive #t))
-(tm-property (open-page-format) (:interactive #t))
+(tm-property (open-page-format) (:interactive #t)
+                                (:applicable (not (selection-active?))))
 (tm-property (open-source-tree-preferences) (:interactive #t))
 (tm-property (open-document-paragraph-format) (:interactive #t))
 (tm-property (open-document-page-format) (:interactive #t))
 (tm-property (open-document-metadata) (:interactive #t))
 (tm-property (open-document-colors) (:interactive #t))
+(tm-property (open-pattern-selector cmd w) (:interactive #t))
+(tm-property (open-background-picture-selector cmd) (:interactive #t))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
@@ -210,6 +235,7 @@
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
 ;(display "Booting programming modes\n")
+(lazy-format (prog prog-format) cpp scheme)
 (lazy-keyboard (prog prog-kbd) in-prog?)
 (lazy-menu (prog prog-menu) prog-format-menu prog-format-icons
 	   prog-menu prog-icons)
@@ -220,12 +246,16 @@
 (lazy-keyboard (source source-kbd) always?)
 (lazy-menu (source source-menu) source-macros-menu source-menu source-icons
            source-transformational-menu source-executable-menu)
-(lazy-define (source macro-edit) has-macro-source? edit-macro-source)
-(lazy-define (source macro-widgets) editable-macro? open-macros-editor
-	     open-macro-editor create-table-macro)
-(tm-property (open-macro-editor l) (:interactive #t))
-(tm-property (create-table-macro l) (:interactive #t))
-(tm-property (open-macros-editor) (:interactive #t))
+(lazy-define (source macro-edit)
+             has-macro-source? edit-macro-source edit-focus-macro-source)
+(lazy-define (source macro-widgets)
+             editable-macro? open-macros-editor
+	     open-macro-editor create-table-macro
+             edit-focus-macro edit-previous-macro)
+(tm-property (open-macro-editor l mode) (:interactive #t))
+(tm-property (create-table-macro l mode) (:interactive #t))
+(tm-property (open-macros-editor mode) (:interactive #t))
+(tm-property (edit-focus-macro) (:interactive #t))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
@@ -242,12 +272,17 @@
 ;(display "Booting graphics mode\n")
 (lazy-keyboard (graphics graphics-kbd) in-active-graphics?)
 (lazy-menu (graphics graphics-menu) graphics-menu graphics-icons)
+(lazy-define (graphics graphics-object)
+             graphics-reset-state graphics-decorations-update)
+(lazy-define (graphics graphics-utils) make-graphics)
 (lazy-define (graphics graphics-edit)
              graphics-busy?
              graphics-reset-context graphics-undo-enabled
              graphics-release-left graphics-release-middle
              graphics-release-right graphics-start-drag-left
              graphics-dragging-left graphics-end-drag-left)
+(lazy-define (graphics graphics-main) graphics-update-proviso
+             graphics-get-proviso graphics-set-proviso)
 (lazy-define (graphics graphics-markup) arrow-with-text arrow-with-text*)
 (define-secure-symbols arrow-with-text arrow-with-text*)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
@@ -260,18 +295,30 @@
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
+;(display "Booting educational features\n")
+(lazy-keyboard (education edu-kbd) in-edu-text?)
+(lazy-menu (education edu-menu) edu-insert-menu)
+;(display* "time: " (- (texmacs-time) boot-start) "\n")
+;(display* "memory: " (texmacs-memory) " bytes\n")
+
 ;(display "Booting dynamic features\n")
 (lazy-keyboard (dynamic fold-kbd) always?)
 (lazy-keyboard (dynamic scripts-kbd) always?)
 (lazy-keyboard (dynamic calc-kbd) always?)
-(lazy-menu (dynamic fold-menu) insert-fold-menu dynamic-menu dynamic-icons)
+(lazy-menu (dynamic fold-menu) insert-fold-menu dynamic-menu dynamic-icons
+           graphics-overlays-menu graphics-screens-menu
+           graphics-focus-overlays-menu graphics-focus-overlays-icons)
 (lazy-menu (dynamic session-menu) insert-session-menu session-help-icons)
 (lazy-menu (dynamic scripts-menu) scripts-eval-menu scripts-plot-menu
            plugin-eval-menu plugin-eval-toggle-menu plugin-plot-menu)
-(lazy-menu (dynamic calc-menu) calc-table-menu calc-insert-menu)
-(lazy-define (dynamic fold-edit) dynamic-make-slides)
+(lazy-menu (dynamic calc-menu) calc-table-menu calc-insert-menu
+           calc-icourse-menu)
+(lazy-menu (dynamic animate-menu) insert-animation-menu animate-toolbar)
+(lazy-define (dynamic fold-edit)
+             screens-switch-to dynamic-make-slides overlays-context?)
 (lazy-define (dynamic session-edit) scheme-eval)
 (lazy-define (dynamic calc-edit) calc-ready? calc-table-renumber)
+(lazy-define (dynamic scripts-plot) open-plots-editor)
 (lazy-initialize (dynamic session-menu) (in-session?))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
@@ -283,10 +330,12 @@
 (lazy-menu (doc help-menu) help-menu)
 (lazy-define (doc tmdoc) tmdoc-expand-help tmdoc-expand-help-manual
              tmdoc-expand-this tmdoc-include)
-(lazy-define (doc docgrep) docgrep-in-doc docgrep-in-src docgrep-in-texts)
+(lazy-define (doc docgrep) docgrep-in-doc docgrep-in-src
+             docgrep-in-texts docgrep-in-recent)
 (lazy-define (doc tmdoc-search) tmdoc-search-style tmdoc-search-tag
              tmdoc-search-parameter tmdoc-search-scheme)
-(lazy-define (doc tmweb) tmweb-convert-dir tmweb-update-dir
+(lazy-define (doc tmweb) youtube-select
+             tmweb-convert-dir tmweb-update-dir
              tmweb-convert-dir-keep-texmacs tmweb-update-dir-keep-texmacs
              tmweb-interactive-build tmweb-interactive-update)
 (lazy-define (doc apidoc) apidoc-all-modules apidoc-all-symbols)
@@ -294,12 +343,12 @@
 (lazy-tmfs-handler (doc docgrep) grep)
 (lazy-tmfs-handler (doc tmdoc) help)
 (lazy-tmfs-handler (doc apidoc) apidoc)
-(define-secure-symbols tmdoc-include)
+(define-secure-symbols tmdoc-include youtube-select)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
 ;(display "Booting converters\n")
-(lazy-format (convert rewrite init-rewrite) texmacs scheme cpp verbatim)
+(lazy-format (convert rewrite init-rewrite) texmacs verbatim)
 (lazy-format (convert tmml init-tmml) tmml)
 (lazy-format (convert latex init-latex) latex)
 (lazy-format (convert html init-html) html)
@@ -329,20 +378,24 @@
 ;(display "Booting database facilities\n")
 (lazy-define (database db-widget) open-db-chooser)
 (lazy-define (database db-menu) db-show-toolbar)
+(lazy-define (database db-convert) db-url?)
 (lazy-define (database bib-db) zealous-bib-import zealous-bib-export)
 (lazy-define (database bib-manage)
              bib-import-bibtex bib-compile bib-attach open-bib-chooser)
+(lazy-define (database bib-local) open-biblio)
 (lazy-menu (database db-menu) db-menu db-toolbar)
 (lazy-tmfs-handler (database db-tmfs) db)
 (lazy-keyboard (database bib-kbd) in-bib?)
+(tm-property (open-biblio) (:interactive #t))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
 ;(display "Booting security tools\n")
-(lazy-define (security wallet wallet-menu) with-wallet)
+(lazy-define (security wallet wallet-menu) expand-with-wallet)
+(tm-define-macro (with-wallet . body) (expand-with-wallet body))
 (lazy-define (security wallet wallet-base)
 	     supports-wallet? wallet-initialized?
-	     wallet-on? wallet-off?)
+	     wallet-on? wallet-off? wallet-get)
 (lazy-menu (security wallet wallet-menu) wallet-preferences-widget)
 (lazy-define (security gpg gpg-edit) tree-export-encrypted
 	     tm-gpg-dialogue-passphrase-decrypt-buffer)
@@ -388,6 +441,11 @@
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
+;(display "Booting editing modes for various special styles\n")
+(lazy-menu (various poster-menu) poster-block-menu)
+;(display* "time: " (- (texmacs-time) boot-start) "\n")
+;(display* "memory: " (texmacs-memory) " bytes\n")
+
 ;(display "Booting plugins\n")
 (for-each lazy-plugin-initialize (plugin-list))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
@@ -400,14 +458,15 @@
 (lazy-define (fonts font-old-menu)
 	     text-font-menu math-font-menu prog-font-menu)
 (lazy-define (fonts font-new-widgets)
-             open-font-selector open-document-font-selector)
+             open-font-selector open-document-font-selector
+             open-document-other-font-selector)
 (tm-property (open-font-selector) (:interactive #t))
 (tm-property (open-document-font-selector) (:interactive #t))
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
 ;(display "Booting regression testing\n")
-(lazy-define (check check-master) check-all run-checks)
+(lazy-define (check check-master) check-all run-checks run-all-tests)
 ;(display* "time: " (- (texmacs-time) boot-start) "\n")
 ;(display* "memory: " (texmacs-memory) " bytes\n")
 
