@@ -27,6 +27,8 @@
 (define-public (nlist? x) (not (list? x)))
 (define-public (nnot x) (not (not x)))
 (define-public-macro (toggle! x) `(set! ,x (not ,x)))
+(define-public (safe-car l) (and (pair? l) (car l)))
+(define-public (safe-cdr l) (and (pair? l) (cdr l)))
 
 (define-public (list-1? x) (and (pair? x) (null? (cdr x))))
 (define-public (nlist-1? x) (not (list-1? x)))
@@ -119,16 +121,26 @@
           (dummy (begin ,@body)))
      return))
 
-(define-public (.. start end)
+(define (range-list start end delta)
   (if (< start end)
-      (cons start (.. (1+ start) end))
+      (cons start (range-list (+ start delta) end delta))
       '()))
 
-(define-public (... start end)
+(define (range-list* start end delta)
   (if (<= start end)
-      (cons start (... (1+ start) end))
+      (cons start (range-list* (+ start delta) end delta))
       '()))
 
+(define-public (.. start end . delta)
+  (if (null? delta)
+      (range-list start end 1)
+      (range-list start end (car delta))))
+
+(define-public (... start end . delta)
+  (if (null? delta)
+      (range-list* start end 1)
+      (range-list* start end (car delta))))
+
 (define-public-macro (for what . body)
   (let ((n (length what)))
     (cond ((== n 2)
