@@ -478,30 +478,21 @@
     "dark green" "dark yellow" "dark orange" "dark brown"
     "red" "magenta" "blue" "cyan"
     "green" "yellow" "orange" "brown"
+    "#faa" "#faf" "#aaf" "#aff"
+    "#afa" "#ffa" "#fa6" "#a66"
     "pastel red" "pastel magenta" "pastel blue" "pastel cyan"
     "pastel green" "pastel yellow" "pastel orange" "pastel brown"))
 
 (define (standard-grey-list)
-  '("black" "darker grey" "dark grey" "light grey"
-    "pastel grey" "white"))
+  '("black" "darker grey" "dark grey" "#a0a0a0"
+    "light grey" "pastel grey" "#f0f0f0" "white"))
 
 (tm-menu (standard-color-menu cmd)
   (tile 8
-    (for (col (standard-color-list))
+    (for (col (append (standard-color-list) (standard-grey-list)))
       (explicit-buttons
         ((color col #f #f 32 24)
-         (cmd col)))))
-  (glue #f #f 0 5)
-  (tile 8
-    (for (col (standard-grey-list))
-      (explicit-buttons
-        ((color col #f #f 32 24)
-         (cmd col))))
-    (for (i (.. 0 2))
-      (when #f
-        (explicit-buttons
-          ((color "#fff0" #f #f 32 24)
-           (noop)))))))
+         (cmd col))))))
 
 (define (gui-make-pick-color x)
   `(menu-dynamic
@@ -514,25 +505,99 @@
 ;; Basic pattern picker
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define (standard-pattern-list scale)
-  (let* ((dir "$TEXMACS_PATH/misc/patterns")
-         (l (url-read-directory dir "*.png"))
+(define-public (get-preferred-list type nr)
+  (with l (get-preference type)
+    (when (string? l) (set! l (string->object l)))
+    (cond ((nlist? l) (list))
+          ((> (length l) nr) (sublist l 0 nr))
+          (else l))))
+
+(define-public (insert-preferred-list type what nr)
+  (let* ((l (get-preferred-list type nr))
+         (i (list-find-index l (cut == <> what)))
+         (r l))
+    (if i (set! r (append (sublist r 0 i)
+                          (sublist r (+ i 1) (length r)))))
+    (set! r (cons what r))
+    (when (> (length r) nr)
+      (set! r (sublist r 0 nr)))
+    (when (!= r l)
+      (set-preference type r))))
+
+(define-public (tm-pattern name . args)
+  (cond ((url-exists? (url-append "$TEXMACS_PATTERN_PATH" (url-tail name)))
+         `(pattern ,(url->unix (url-tail name)) ,@args))
+        ((string-starts? (url->unix (url->delta-unix name)) "../")
+         (when (url? name) (set! name (url->system name)))
+         `(pattern ,name ,@args))
+        (else
+         `(pattern ,(url->unix (url->delta-unix name)) ,@args))))
+
+(tm-menu (my-pattern-menu cmd)
+  (tile 8
+    (for (col (get-preferred-list "my patterns" 16))
+      (with args (cons* (cadr col) "100%" "100@" (cddddr col))
+        (with col2 (apply tm-pattern args)
+          (explicit-buttons
+            ((color col2 #f #f 32 32)
+             (cmd col))))))))
+
+(define (standard-pattern-list dir scale)
+  (let* ((l1 (url-read-directory dir "*.png"))
+         (l2 (url-read-directory dir "*.jpg"))
+         (l3 (url-read-directory dir "*.gif"))
+         (l (append l1 l2 l3))
          (d (map (cut url-delta (string-append dir "/x") <>) l))
          (f (map (lambda (x) (string-append dir "/" (url->unix x))) d)))
-    (map (lambda (x) `(pattern ,x ,scale "")) f)))
+    (map (lambda (x) (tm-pattern x scale "")) f)))
 
-(tm-menu (standard-pattern-menu cmd scale)
+(tm-menu (standard-pattern-menu cmd dir scale)
   (tile 8
-    (for (col (standard-pattern-list scale))
-      (explicit-buttons
-        ((color col #f #f 32 24)
-         (cmd col))))))
+    (for (col (standard-pattern-list dir scale))
+      (with col2 (tm-pattern (cadr col) "100%" "100@")
+        (explicit-buttons
+          ((color col2 #f #f 32 32)
+           (cmd col)))))))
+
+(tm-menu (big-pattern-menu cmd dir scale)
+  (tile 6
+    (for (col (standard-pattern-list dir scale))
+      (with col2 (tm-pattern (cadr col) "100%" "100@")
+        (explicit-buttons
+          ((color col2 #f #f 90 90)
+           (cmd col)))))))
+
+(define-public (clipart-list)
+  (list-filter
+   (list (list "Dot hatches" "$TEXMACS_PATH/misc/patterns/dots-hatches")
+         (list "Line hatches" "$TEXMACS_PATH/misc/patterns/lines-default")
+         (list "Artistic hatches" "$TEXMACS_PATH/misc/patterns/lines-artistic")
+         (list "Textile" "$TEXMACS_PATH/misc/patterns/textile")
+         (list "Hatch" "/opt/local/share/openclipart/special/patterns")
+         (list "Personal" "~/patterns")
+         (list "Simple" "~/simple-tiles"))
+   (lambda (p) (url-exists? (cadr p)))))
+
+(tm-menu (clipart-pattern-menu cmd scale)
+  (for (p (clipart-list))
+    (-> (eval (car p))
+        (dynamic (big-pattern-menu cmd (cadr p) scale)))))
 
 (define (gui-make-pick-background x)
   `(menu-dynamic
      (dynamic (standard-color-menu (lambda (answer) ,@(cddr x))))
-     (glue #f #f 0 5)
-     (dynamic (standard-pattern-menu (lambda (answer) ,@(cddr x)) ,(cadr x)))))
+     ---
+     (dynamic (standard-pattern-menu (lambda (answer) ,@(cddr x))
+                                     "$TEXMACS_PATH/misc/patterns/vintage"
+                                     ,(cadr x)))
+     (when (nnull? (get-preferred-list "my patterns" 16))
+       ---
+       (dynamic (my-pattern-menu (lambda (answer) ,@(cddr x)))))
+     ;;(assuming (nnull? (clipart-list))
+     ;;  ---
+     ;;  (dynamic (clipart-pattern-menu (lambda (answer) ,@(cddr x))
+     ;;                                 ,(cadr x))))
+     ))
 
 (extend-table gui-make-table
   (pick-background ,gui-make-pick-background))
