@@ -117,6 +117,11 @@
     ("[ \xfe" (make 'bmatrix))
     ("| \xfe" (make 'det))))
 
+(when (os-macos?)
+  (kbd-map
+    (:mode in-math-like-macos?)
+    ("math A-n" (make-wide "~"))))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Main keyboard shortcuts
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -1685,14 +1690,14 @@
   ("math:greek c var" "<sigma>")
   ("math:greek t" "<tau>")
   ("math:greek u" "<upsilon>")
-  ("math:greek f" "<varphi>")
-  ("math:greek f var" "<phi>")
   ("math:greek y" "<psi>")
   ("math:greek q" "<chi>")
   ("math:greek w" "<omega>")
   ("math:greek w var" "<mho>")
   ("math:greek v" "<phi>")
   ("math:greek v var" "<varphi>")
+  ("math:greek f" "<varphi>")
+  ("math:greek f var" "<phi>")
   ("math:greek A" "<Alpha>")
   ("math:greek B" "<Beta>")
   ("math:greek G" "<Gamma>")
@@ -1718,12 +1723,12 @@
   ("math:greek C" "<Sigma>")
   ("math:greek T" "<Tau>")
   ("math:greek U" "<Upsilon>")
-  ("math:greek F" "<Phi>")
   ("math:greek Y" "<Psi>")
   ("math:greek Q" "<Chi>")
   ("math:greek W" "<Omega>")
   ("math:greek W var" "<Mho>")
-  ("math:greek V" "<Phi>"))
+  ("math:greek V" "<Phi>")
+  ("math:greek F" "<Phi>"))
 
 (kbd-map
   (:mode in-math-not-hybrid?)
@@ -1739,8 +1744,6 @@
   ("e var var" "<mathe>")
   ("e var var var" "<epsilon>")
   ("e var var var var" "<backepsilon>")
-  ("f var" "<varphi>")
-  ("f var var" "<phi>")
   ("g var" "<gamma>")
   ("g var var" "<matheuler>")
   ("h var" "<eta>")
@@ -1771,6 +1774,8 @@
   ("u var" "<upsilon>")
   ("v var" "<phi>")
   ("v var var" "<varphi>")
+  ("f var" "<varphi>")
+  ("f var var" "<phi>")
   ("w var" "<omega>")
   ("w var var" "<mho>")
   ("x var" "<xi>")
@@ -1794,7 +1799,6 @@
   ("E var var" "<exists>")
   ("E var var var" "<Exists>")
   ("E var var var var" "<Backepsilon>")
-  ("F var" "<Phi>")
   ("G var" "<Gamma>")
   ("G var var" "<gimel>")
   ("G var var var" "<mathGamma>")
@@ -1825,6 +1829,7 @@
   ("U var" "<Upsilon>")
   ("V var" "<Phi>")
   ("V var var" "<nabla>")
+  ("F var" "<Phi>")
   ("W var" "<Omega>")
   ("W var var" "<Mho>")
   ("X var" "<Xi>")
@@ -1934,14 +1939,14 @@
   ("math:bold:greek c var" "<b-sigma>")
   ("math:bold:greek t" "<b-tau>")
   ("math:bold:greek u" "<b-upsilon>")
-  ("math:bold:greek f" "<b-varphi>")
-  ("math:bold:greek f var" "<b-phi>")
   ("math:bold:greek y" "<b-psi>")
   ("math:bold:greek q" "<b-chi>")
   ("math:bold:greek w" "<b-omega>")
   ("math:bold:greek w var" "<b-mho>")
   ("math:bold:greek v" "<b-phi>")
   ("math:bold:greek v var" "<b-varphi>")
+  ("math:bold:greek f" "<b-varphi>")
+  ("math:bold:greek f var" "<b-phi>")
   ("math:bold:greek A" "<b-Alpha>")
   ("math:bold:greek B" "<b-Beta>")
   ("math:bold:greek G" "<b-Gamma>")
@@ -1965,12 +1970,12 @@
   ("math:bold:greek C" "<b-Sigma>")
   ("math:bold:greek T" "<b-Tau>")
   ("math:bold:greek U" "<b-Upsilon>")
-  ("math:bold:greek F" "<b-Phi>")
   ("math:bold:greek Y" "<b-Psi>")
   ("math:bold:greek Q" "<b-Chi>")
   ("math:bold:greek W" "<b-Omega>")
   ("math:bold:greek W var" "<b-Mho>")
   ("math:bold:greek V" "<b-Phi>")
+  ("math:bold:greek F" "<b-Phi>")
 
   ("math:bold a var" "<b-alpha>")
   ("math:bold b var" "<b-beta>")
@@ -1980,8 +1985,6 @@
   ("math:bold e var" "<b-varepsilon>")
   ("math:bold e var var" "<b-epsilon>")
   ("math:bold e var var var" "<b-backepsilon>")
-  ("math:bold f var" "<b-varphi>")
-  ("math:bold f var var" "<b-phi>")
   ("math:bold g var" "<b-gamma>")
   ("math:bold h var" "<b-eta>")
   ("math:bold i var" "<b-iota>")
@@ -2007,6 +2010,8 @@
   ("math:bold u var" "<b-upsilon>")
   ("math:bold v var" "<b-phi>")
   ("math:bold v var var" "<b-varphi>")
+  ("math:bold f var" "<b-varphi>")
+  ("math:bold f var var" "<b-phi>")
   ("math:bold w var" "<b-omega>")
   ("math:bold w var var" "<b-mho>")
   ("math:bold x var" "<b-xi>")
@@ -2018,7 +2023,6 @@
   ("math:bold D var" "<b-Delta>")
   ("math:bold E var" "<b-Epsilon>")
   ("math:bold E var var" "<b-Backepsilon>")
-  ("math:bold F var" "<b-Phi>")
   ("math:bold G var" "<b-Gamma>")
   ("math:bold H var" "<b-Eta>")
   ("math:bold I var" "<b-Iota>")
@@ -2036,6 +2040,7 @@
   ("math:bold T var" "<b-Tau>")
   ("math:bold U var" "<b-Upsilon>")
   ("math:bold V var" "<b-Phi>")
+  ("math:bold F var" "<b-Phi>")
   ("math:bold W var" "<b-Omega>")
   ("math:bold W var var" "<b-Mho>")
   ("math:bold X var" "<b-Xi>")
@@ -2102,8 +2107,6 @@
   ("math:up d var" "<up-delta>")
   ("math:up e var" "<up-varepsilon>")
   ("math:up e var var" "<up-epsilon>")
-  ("math:up f var" "<up-varphi>")
-  ("math:up f var var" "<up-phi>")
   ("math:up g var" "<up-gamma>")
   ("math:up h var" "<up-eta>")
   ("math:up i var" "<up-iota>")
@@ -2129,6 +2132,8 @@
   ("math:up u var" "<up-upsilon>")
   ("math:up v var" "<up-phi>")
   ("math:up v var var" "<up-varphi>")
+  ("math:up f var" "<up-varphi>")
+  ("math:up f var var" "<up-phi>")
   ("math:up w var" "<up-omega>")
   ("math:up x var" "<up-xi>")
   ("math:up y var" "<up-psi>")
@@ -2138,7 +2143,6 @@
   ;;("math:up C var" "<up-Sigma>")
   ;;("math:up D var" "<up-Delta>")
   ;;("math:up E var" "<up-Epsilon>")
-  ;;("math:up F var" "<up-Phi>")
   ;;("math:up G var" "<up-Gamma>")
   ;;("math:up H var" "<up-Eta>")
   ;;("math:up I var" "<up-Iota>")
@@ -2155,6 +2159,7 @@
   ;;("math:up T var" "<up-Tau>")
   ;;("math:up U var" "<up-Upsilon>")
   ;;("math:up V var" "<up-Phi>")
+  ;;("math:up F var" "<up-Phi>")
   ;;("math:up W var" "<up-Omega>")
   ;;("math:up W var var" "<up-Mho>")
   ;;("math:up X var" "<up-Xi>")
@@ -2221,8 +2226,6 @@
   ("math:bold:up d var" "<b-up-delta>")
   ("math:bold:up e var" "<b-up-varepsilon>")
   ("math:bold:up e var var" "<b-up-epsilon>")
-  ("math:bold:up f var" "<b-up-varphi>")
-  ("math:bold:up f var var" "<b-up-phi>")
   ("math:bold:up g var" "<b-up-gamma>")
   ("math:bold:up h var" "<b-up-eta>")
   ("math:bold:up i var" "<b-up-iota>")
@@ -2248,6 +2251,8 @@
   ("math:bold:up u var" "<b-up-upsilon>")
   ("math:bold:up v var" "<b-up-phi>")
   ("math:bold:up v var var" "<b-up-varphi>")
+  ("math:bold:up f var" "<b-up-varphi>")
+  ("math:bold:up f var var" "<b-up-phi>")
   ("math:bold:up w var" "<b-up-omega>")
   ("math:bold:up x var" "<b-up-xi>")
   ("math:bold:up y var" "<b-up-psi>")
@@ -2257,7 +2262,6 @@
   ;;("math:bold:up C var" "<b-up-Sigma>")
   ;;("math:bold:up D var" "<b-up-Delta>")
   ;;("math:bold:up E var" "<b-up-Epsilon>")
-  ;;("math:bold:up F var" "<b-up-Phi>")
   ;;("math:bold:up G var" "<b-up-Gamma>")
   ;;("math:bold:up H var" "<b-up-Eta>")
   ;;("math:bold:up I var" "<b-up-Iota>")
@@ -2274,6 +2278,7 @@
   ;;("math:bold:up T var" "<b-up-Tau>")
   ;;("math:bold:up U var" "<b-up-Upsilon>")
   ;;("math:bold:up V var" "<b-up-Phi>")
+  ;;("math:bold:up F var" "<b-up-Phi>")
   ;;("math:bold:up W var" "<b-up-Omega>")
   ;;("math:bold:up W var var" "<b-up-Mho>")
   ;;("math:bold:up X var" "<b-up-Xi>")
