@@ -14,6 +14,7 @@
 (texmacs-module (text text-edit)
   (:use (utils library tree)
 	(utils edit variants)
+	(utils edit selections)
 	(text text-drd)
 	(generic format-edit)))
 
@@ -64,6 +65,7 @@
   (doc-title-inactive-tag-list))
 
 (tm-define (make-doc-data)
+  (:applicable (not (selection-active-non-small?)))
   (insert-go-to '(doc-data (doc-title "")) '(0 0 0)))
 
 (tm-define (make-doc-data-element l)
@@ -269,14 +271,42 @@
 	   (with sp (path-previous-section bt bp)
 	     (and (!= sp bp) (path->tree (append (tree->path bt) sp))))))))
 
+(define (selection-trim-ending)
+  (if (selection-active-any?)
+    (with st (selection-tree)
+      (if (and (not  (tree-atomic? st ))
+               (tree-empty? (tree-ref st :last)))             
+        (begin 
+          (selection-set 
+            (selection-get-start) 
+            (path-previous (root-tree) (selection-get-end)))
+          (selection-trim-ending))))))
+
+(define (make-section-aux l flag)
+  (if (selection-active-any?) 
+    (let 
+      ((cp (cursor-path))
+       (selstart (selection-get-start)))
+      (selection-trim-ending)
+      (if (tree-multi-paragraph? (selection-tree))
+        (set-message "make-section error" "invalid multi-paragraph selection")
+        (with selend  (selection-get-end)
+          (make l)
+          (if flag (make-return-before)
+            (if (or (path-less-eq? cp selstart) (path-less? selend cp))
+              ;; reposition cursor when its path still exists
+              (go-to cp))))))
+    (if (not (make-return-after))
+      (begin 
+        (make l)
+        (if flag (make-return-before))))))
+
 (tm-define (make-section l)
-  (if (or (selection-active-any?) (not (make-return-after)))
-      (make l)))
+  (:applicable (not (selection-active-non-small?)))
+  (make-section-aux l #f))
 
 (tm-define (make-unnamed-section l)
-  (if (or (selection-active-any?) (not (make-return-after)))
-      (make l)
-      (make-return-before)))
+  (make-section-aux l #t))
 
 (tm-define (kbd-enter t shift?)
   (:require (section-context? t))
@@ -306,15 +336,19 @@
       (tree-in? t (enumerate-tag-list))))
 
 (tm-define (make-tmlist l)
-  (make l)
-  (make-item))
+  (with flag? (and (selection-active-non-small?)
+                   (in? l (description-tag-list)))
+    (wrap-selection-any
+      (make l)
+      (if flag? (insert '(item* "")) (make-item)))))
 
 (tm-define (make-item)
   (if (not (make-return-after))
       (with lab (inside-which (list-tag-list))
 	(cond ((in? lab (itemize-tag-list)) (make 'item))
 	      ((in? lab (enumerate-tag-list)) (make 'item))
-	      ((in? lab (description-tag-list)) (make 'item*))))))
+	      ((in? lab (description-tag-list)) (make 'item*))
+              (else (make 'item))))))
 
 (tm-define (kbd-enter t shift?)
   (:require (list-context? t))
@@ -352,19 +386,34 @@
   (:require (in? l (list "itemize-levels" "enumerate-levels")))
   (list "1" "2" "3" "4"))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Hyphenation
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-define (hyphenate-selection-as hyph)
+  (:interactive #t)
+  (:argument hyph "Hyphenate as")
+  (:proposals hyph (list (tm->string (selection-tree))))
+  (with ins `(hyphenate-as ,hyph ,(selection-tree))
+    (clipboard-cut "null")
+    (insert ins)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Inserting formulas
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
 (tm-define (make-equation)
+  (:applicable (not (selection-active-non-small?)))
   (make 'equation)
   (temp-proof-fix))
 
 (tm-define (make-equation*)
+  (:applicable (not (selection-active-non-small?)))
   (make 'equation*)
   (temp-proof-fix))
 
 (tm-define (make-eqnarray*)
+  (:applicable (not (selection-active-non-small?)))
   (make 'eqnarray*)
   (temp-proof-fix))
 
@@ -384,14 +433,57 @@
   (if (not (make-return-after))
       (insert (list (string->symbol env) aux name '(document "")))))
 
-(tm-define (make-bib style file-name)
-  (:argument style "Bibliography style")
-  (:proposals style '("tm-plain" "tm-alpha" "tm-acm" "tm-elsart-num"
-                      "tm-ieeetr" "tm-siam" "tm-unsrt"))
+(define (normalized-bib-name f)
+  (if (string? f) f
+      (let* ((r (url-delta (current-buffer) f))
+             (n (if (== (url-suffix r) "bib") (url-unglue r 4) r)))
+        (url->string n))))
+
+(tm-define (make-bib file-name)
   (:argument file-name "Bibliography file")
+  (let* ((name (normalized-bib-name file-name))
+         (aux (if (context-has? "bib-prefix") (get-env "bib-prefix") "bib")))
+    (if (not (make-return-after))
+        (insert-go-to `(bibliography ,aux "tm-plain" ,name (document ""))
+                      '(3 0 0)))))
+
+(tm-define (make-database-bib)
   (with aux (if (context-has? "bib-prefix") (get-env "bib-prefix") "bib")
     (if (not (make-return-after))
-        (insert (list 'bibliography aux style file-name '(document ""))))))
+        (insert-go-to `(bibliography ,aux "tm-plain" "" (document ""))
+                      '(3 0 0)))))
+
+(tm-define (automatic-section-context? t)
+  (tree-in? t (automatic-section-tag-list)))
+
+(define (automatic-name-var t)
+  (cond ((tm-func? t 'table-of-contents) "table-of-contents-text")
+        ((tm-func? t 'bibliography) "bibliography-text")
+        ((tm-func? t 'the-index) "index-text")
+        ((tm-func? t 'the-glossary) "glossary-text")
+        ((tm-func? t 'list-of-figures) "list-of-figures")
+        ((tm-func? t 'list-of-tables) "list-of-tables")
+        (else #f)))
+
+(define (automatic-section-name)
+  (with-innermost t automatic-section-context?
+    (let* ((var (automatic-name-var t))
+           (val (if var (get-env-tree var) "")))
+      (when (tm-func? val 'macro 1)
+        (set! val (tm-ref val 0)))
+      (when (and (tm-func? val 'localize 1) (tm-atomic? (tm-ref val 0)))
+        (set! val (tm-ref val 0)))
+      (if (tm-atomic? val) (tm->string val) ""))))
+
+(tm-define (automatic-section-rename new-name)
+  (:argument new-name "New name")
+  (:proposals new-name (list (automatic-section-name)))
+  (with-innermost t automatic-section-context?
+    (when t
+      (let* ((l (tree-label t))
+             (l* (symbol-append l '*)))
+        (tree-set t `(,l* ,@(cDr (tm-children t))
+                          ,new-name ,(tm-ref t :last)))))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Editing enunciations
@@ -492,6 +584,27 @@
 	  (tree-insert! t (- (tree-arity t) 1) '((document "")))
 	  (tree-go-to t (- (tree-arity t) 2) :start)))))
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Possible to use a custom note symbol
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-define (detached-note-context? t)
+  (tree-in? t (detached-note-tag-list)))
+
+(tm-define (auto-note-context? t)
+  (tree-in? t (auto-note-tag-list)))
+
+(tm-define (custom-note-context? t)
+  (tree-in? t (custom-note-tag-list)))
+
+(tm-define (note-toggle-custom t)
+  (let* ((l (symbol-toggle-number (tree-label t)))
+         (c (tree-children t)))
+    (if (auto-note-context? t)
+        (tree-insert! t (tree-arity t) (list "<dag>"))
+        (tree-remove! t (- (tree-arity t) 1) 1))
+    (tree-assign-node! t l)))
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Possible to change the title of titled environments
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -507,14 +620,12 @@
          (tree-set! t `(render-theorem "" ,(tree-ref t 0))))
         ((tree-in? t (numbered-unnumbered-append (remark-tag-list)))
          (tree-set! t `(render-remark "" ,(tree-ref t 0))))
-        ((tree-in? t '(question))
-         (tree-set! t `(render-theorem "" ,(tree-ref t 0))))
-        ((tree-in? t '(answer))
+        ((tree-in? t '(question answer))
          (tree-set! t `(render-remark "" ,(tree-ref t 0))))
         ((tree-in? t (numbered-unnumbered-append (exercise-tag-list)))
          (tree-set! t `(render-exercise "" ,(tree-ref t 0))))
         ((tree-in? t (numbered-unnumbered-append (solution-tag-list)))
-         (tree-set! t `(render-solution "" ,(tree-ref t 0))))
+         (tree-set! t `(render-exercise "" ,(tree-ref t 0))))
         ((tree-in? t '(proof))
          (tree-set! t `(render-proof "" ,(tree-ref t 0))))
         ((tree-in? t (numbered-unnumbered-append (small-figure-tag-list)))
@@ -561,11 +672,19 @@
            (tree-set! t `(,l ,(tree-ref t 0)))
            (tree-go-to t 0 :end)))))
 
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "padding-above" "padding-below")))
+  (list "0fn" "0.5fn" "1fn" "1.5fn" "2fn" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-in? t '(padded padded-titled)))
   (list (list "padding-above" "Above")
         (list "padding-below" "Below")))
 
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "overlined-sep" "underlined-sep")))
+  (list "0sep" "0.5sep" "1sep" "1.5sep" "2sep" :other))
+
 (tm-define (customizable-parameters t)
   (:require (tree-in? t '(overlined overlined-titled)))
   (list (list "padding-above" "Above")
@@ -589,29 +708,37 @@
   (:require (tree-in? t '(framed framed-titled)))
   (list (list "padding-above" "Above")
         (list "padding-below" "Below")
-        (list "framed-vsep" "Inner")
-        (list "framed-hsep" "Indentation")
         (list "framed-color" "Color")))
 
-(tm-define (customizable-parameters t)
-  (:require (tree-is? t 'ornamented))
-  (list (list "padding-above" "Above")
-        (list "padding-below" "Below")
-        (list "ornament-vpadding" "Inner")
-        (list "ornament-hpadding" "Indentation")
-        (list "ornament-color" "Color")
-        (list "ornament-shape" "Shape")))
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "ornament-hpadding" "ornament-vpadding")))
+  (list "0spc" "0.5spc" "1spc" "1.5spc" "2spc" :other))
+
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "ornament-border")))
+  (list "0ln" "0.5ln" "1ln" "2ln" "3ln" "4ln" "5ln" :other))
 
 (tm-define (customizable-parameters t)
-  (:require (tree-is? t 'ornamented-titled))
+  (:require (tree-in? t '(ornamented decorated)))
   (list (list "padding-above" "Above")
         (list "padding-below" "Below")
         (list "ornament-vpadding" "Inner")
         (list "ornament-hpadding" "Indentation")
-        (list "ornament-color" "Color")
         (list "ornament-shape" "Shape")
-        (list "ornament-extra-color" "Title color")
-        (list "ornament-title-style" "Title style")))
+        (list "ornament-color" "Color")
+        (list "ornament-border" "Border")))
+
+(tm-define (customizable-parameters t)
+  (:require (tree-in? t '(ornamented-titled decorated-titled)))
+  (list (list "padding-above" "Above")
+        (list "padding-below" "Below")
+        (list "ornament-vpadding" "Inner")
+        (list "ornament-hpadding" "Indentation")
+        (list "ornament-shape" "Shape")
+        (list "ornament-color" "Color")
+        (list "ornament-border" "Border")
+        (list "ornament-title-style" "Title style")
+        (list "ornament-extra-color" "Title color")))
 
 (tm-define (customizable-parameters t)
   (:require (tree-is? t 'ornament))
@@ -630,3 +757,157 @@
         (list "ornament-border" "Border width")
         (list "ornament-hpadding" "Horizontal padding")
         (list "ornament-vpadding" "Vertical padding")))
+
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "frame-hpadding" "frame-vpadding")))
+  (list "0tab" "0.5tab" "1tab" "1.5tab" "2tab" :other))
+
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "frame-thickness")))
+  (list "0.2" "0.5" "1" "1.5" "2" "3" "4" "5" :other))
+
+(tm-define (customizable-parameters t)
+  (:require (tree-in? t (art-frame-tag-list)))
+  (list (list "frame-thickness" "Thickness")
+        (list "frame-recolor" "Recolor")
+        (list "frame-hpadding" "Horizontal padding")
+        (list "frame-vpadding" "Vertical padding")))
+
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "shadow-elevation")))
+  (list "0.2" "0.5" "1" "1.5" "2" "3" "4" "5" :other))
+
+(tm-define (parameter-choice-list var)
+  (:require (in? var (list "shadow-plain")))
+  (list "false" "true"))
+
+(tm-define (customizable-parameters t)
+  (:require (tree-in? t (shadow-tag-list)))
+  (list (list "shadow-elevation" "Elevation")
+        (list "shadow-recolor" "Recolor")
+        (list "shadow-plain" "Plain")))
+
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Floating objects and environments
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+
+(tm-define (float-context? t)
+  (tree-in? t '(float wide-float)))
+
+(tm-define (footnote-context? t)
+  (tree-in? t '(footnote wide-footnote)))
+
+(tm-define (float-or-footnote-context? t)
+  (tree-in? t '(float wide-float footnote wide-footnote)))
+
+(tm-define (phantom-float-context? t)
+  (tree-is? t 'phantom-float))
+
+(tm-define (rich-float-context? t)
+  (cond ((tree-in? t '(float wide-float)) #t)
+        ((tree-in? t '(big-figure big-figure*
+                       big-table big-table*
+                       algorithm algorithm*
+                       document concat))
+         (and (tree-up t) (rich-float-context? (tree-up t))))
+        (else #f)))
+
+(tm-define (floatable-context? t)
+  (and (tree-in? t '(big-figure big-figure*
+                     big-table big-table*
+                     algorithm algorithm*))
+       (not (rich-float-context? t))
+       (or (tree-is? t :up 'document)
+           (and (tree-is? t :up 'with)
+                (tree-is? t :up :up 'document)))))
+
+(define (with-wide? w)
+  (and (tree-is? w 'with)
+       (== (tree-arity w) 3)
+       (tm-equal? (tree-ref w 0) "par-columns")
+       (tm-equal? (tree-ref w 1) "1")))
+
+(tm-define (turn-floating t)
+  (when (floatable-context? t)
+    (when (tree-is? t :up 'with)
+      (set! t (tree-up t)))
+    (with f (if (with-wide? t)
+                `(wide-float "float" "thb" ,(tree-ref t 2))
+                `(float "float" "thb" ,t))
+      (tree-set! t f)
+      (tree-go-to t :start)
+      (remove-text #f)
+      (tree-go-to t :end))))
+
+(define (floatable-path t)
+  (if (or (tm-func? t 'document 1)
+          (tm-func? t 'with 3)
+          (tm-in? t '(big-figure big-figure*
+                      big-table big-table*
+                      algorithm algorithm*)))
+      (with last (- (tm-arity t) 1)
+        (cons last (floatable-path (tm-ref t :last))))
+      (path-end t '())))
+
+(tm-define (turn-non-floating t)
+  (when (float-context? t)
+    (with body (tree-copy (tree-ref t :last))
+      (when (tree-is? t 'wide-float)
+        (set! body (tm->tree `(with "par-columns" "1" ,body))))
+      (when (not (tree-is? body 'document))
+        (set! body (tm->tree `(document ,body))))
+      (tree-cut t)
+      (insert-return)
+      (insert-go-to body (floatable-path body)))))
+
+(tm-define (float-wide? t)
+  (and-with f (tree-search-upwards t float-or-footnote-context?)
+    (tree-in? f '(wide-float wide-footnote))))
+
+(tm-define (test-float-wide? . args)
+  (float-wide? (focus-tree)))
+(tm-define (float-toggle-wide t)
+  (:check-mark "v" test-float-wide?)
+  (and-with f (tree-search-upwards t float-or-footnote-context?)
+    (cond ((tree-is? f 'float) (tree-assign-node f 'wide-float))
+          ((tree-is? f 'wide-float) (tree-assign-node f 'float))
+          ((tree-is? f 'footnote) (tree-assign-node f 'wide-footnote))
+          ((tree-is? f 'wide-footnote) (tree-assign-node f 'footnote)))))
+
+(tm-define (floatable-wide? t)
+  (and-with w (tree-up t)
+    (with-wide? w)))
+
+(tm-define (test-floatable-wide? . args)
+  (floatable-wide? (focus-tree)))
+(tm-define (floatable-toggle-wide t)
+  (:check-mark "v" test-floatable-wide?)
+  (and-with w (tree-up t)
+    (if (with-wide? w)
+        (tree-set w (tree-ref w 2))
+        (tree-set t `(with "par-columns" "1" ,t)))))
+
+(tm-define (cursor-at-anchor?)
+  (with t (cursor-tree)
+    (float-or-footnote-context? t)))
+
+(tm-define (go-to-anchor)
+  (cond ((or (inside? 'float) (inside? 'wide-float))
+         (with-innermost t float-context?
+           (tree-go-to t :end)))
+        ((or (inside? 'footnote) (inside? 'wide-footnote))
+         (with-innermost t footnote-context?
+           (tree-go-to t :end)))))
+
+(tm-define (go-to-float)
+  (with t (cursor-tree)
+    (cond ((float-context? t)
+           (tree-go-to t 2 :start))
+          ((footnote-context? t)
+           (tree-go-to t 0 :start)))))
+
+(tm-define (cursor-toggle-anchor)
+  (:check-mark "v" cursor-at-anchor?)
+  (if (cursor-at-anchor?)
+      (go-to-float)
+      (go-to-anchor)))
